* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF; *ODS LISTING;

***********************************************************************************;
*******             BEGIN DATA MANIPULATION FOR CHAPTER 3a EXAMPLE          *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Define global variable for file location to be replaced in code below;
%LET filesave = C:\Dropbox\22_PSQF6271\PSQF6271_Example3a;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* Import and stack chapter 3 two-occasion multivariate data;
* Create new variable on left from old variable on right, OUTPUT writes data;
DATA work.Example3a; SET filesave.SAS_Chapter3a;
occasion=1; outcome=outcome1; OUTPUT;
occasion=2; outcome=outcome2; OUTPUT;
DROP outcome1 outcome2; 
LABEL occasion = "occasion: 1=pre-test, 2=post-test"
      outcome  = "outcome: Learning Outcome";  
RUN;

* Center predictors for analysis;
DATA work.Example3a; SET work.Example3a; 
time = occasion - 1; treat = group - 1; 
LABEL time  = "time: 0=pre-test, 1=post-test"
      treat = "treat: 0=control, 1=treatment";
RUN;

* Sort by person and occasion;
PROC SORT DATA=work.Example3a; BY PersonID occasion; RUN;


***********************************************************************************;
*******                       BEGIN EXAMPLE 3a MODELS                       *******;
***********************************************************************************;

* Open external file to save results to;
ODS RTF FILE="&filesave.\SAS_Example3a_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

* CLASS= means per group and time, WAYS= means overall=0, per category=1, per cell=2;
TITLE1 "Chapter 3a Example: Means by group and occasion for learning outcome";
PROC MEANS NDEC=2 MEAN STDERR MIN MAX DATA=work.Example3a; 
     CLASS group occasion; WAYS 0 1 2;
     VAR outcome;
RUN; TITLE1;

TITLE "Eq 3.1: Empty Between-Person model via SAS MIXED";
PROC MIXED DATA=work.Example3a NOCLPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS PersonID occasion;
     MODEL outcome = / SOLUTION CL ALPHA=.05 DDFM=BW;
     REPEATED occasion / R RCORR TYPE=VC SUBJECT=PersonID; 
RUN; TITLE;

TITLE "Eq 3.2: Empty Within-Person model via SAS MIXED";
PROC MIXED DATA=work.Example3a NOCLPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS PersonID occasion;
     MODEL outcome =  / SOLUTION CL ALPHA=.05 DDFM=BW;
     REPEATED occasion / R RCORR TYPE=CS SUBJECT=PersonID;
RUN; TITLE;

TITLE1 "Eq 3.7 (top): Between-Person Conditional (Predictor) Model via SAS MIXED";
TITLE2 "Not using CLASS statement, manually dummy coding group and time"; 
PROC MIXED DATA=work.Example3a NOCLPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS PersonID occasion;
     MODEL outcome = time treat time*treat / SOLUTION CL ALPHA=.05 DDFM=BW;
     REPEATED occasion / R RCORR TYPE=VC SUBJECT=PersonID; * Est: Add / CL ALPHA=.05 for 95% CI;
     ESTIMATE "Control Group Mean at Pre-Test"      intercept 1 time 0 treat 0 time*treat 0 / CL ALPHA=.05;
     ESTIMATE "Control Group Mean at Post-Test"     intercept 1 time 1 treat 0 time*treat 0;
     ESTIMATE "Treatment Group Mean at Pre-Test"    intercept 1 time 0 treat 1 time*treat 0;
     ESTIMATE "Treatment Group Mean at Post-Test"   intercept 1 time 1 treat 1 time*treat 1;
     ESTIMATE "Time Slope for Control Group"        time  1 time*treat 0;
     ESTIMATE "Time Slope for Treatment Group"      time  1 time*treat 1;
     ESTIMATE "Group Slope at Pre-Test"             treat 1 time*treat 0;
     ESTIMATE "Group Slope at Post-Test"            treat 1 time*treat 1;
     ESTIMATE "Time*Group Interaction Slope"        time*treat 1;
     CONTRAST "DF=3 Joint F-test for Model R2"      time 1, treat 1, time*treat 1 / CHISQ; 
RUN; TITLE1; TITLE2;

TITLE1 "Eq 3.7 (bottom): Within-Person Conditional (Predictor) Model via SAS MIXED";
TITLE2 "Not using CLASS statement, manually dummy coding group and time";
PROC MIXED DATA=work.Example3a NOCLPRINT COVTEST NAMELEN=100 IC METHOD=REML;
     CLASS PersonID occasion;
     MODEL outcome = time treat time*treat / SOLUTION CL ALPHA=.05 DDFM=BW;
     REPEATED occasion / R RCORR TYPE=CS SUBJECT=PersonID; * Est: Add / CL ALPHA=.05 for 95% CI;
     ESTIMATE "Control Group Mean at Pre-Test"      intercept 1 time 0 treat 0 time*treat 0 / CL ALPHA=.05;
     ESTIMATE "Control Group Mean at Post-Test"     intercept 1 time 1 treat 0 time*treat 0;
     ESTIMATE "Treatment Group Mean at Pre-Test"    intercept 1 time 0 treat 1 time*treat 0;
     ESTIMATE "Treatment Group Mean at Post-Test"   intercept 1 time 1 treat 1 time*treat 1;
     ESTIMATE "Time Slope for Control Group"        time  1 time*treat 0;
     ESTIMATE "Time Slope for Treatment Group"      time  1 time*treat 1;
     ESTIMATE "Group Slope at Pre-Test"             treat 1 time*treat 0;
     ESTIMATE "Group Slope at Post-Test"            treat 1 time*treat 1;
     ESTIMATE "Time*Group Interaction Slope"        time*treat 1;
     CONTRAST "DF=3 Joint F-test for Model R2"      time 1, treat 1, time*treat 1 / CHISQ; 
RUN; TITLE1; TITLE2;


****** END CHAPTER 3a MODELS ******;

* Close external file of saved results;
ODS RTF CLOSE;
