// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
******     BEGIN DATA MANIPULATION OF CHAPTER 3a TWO-OCCASION EXAMPLE    *******
******                CHANGE "filesave" to your directory                *******
********************************************************************************

// Define global variable for file location to be replaced in code below
   global filesave "C:\Dropbox\22_PSQF6271\PSQF6271_Example3a"

// Import and stack chapter 3a two-occasion multivariate data
// List time-varying variables first, i(level2ID) j(newtimeID)
   use "$filesave\STATA_Chapter3a.dta", clear
   reshape long outcome, i(personid) j(occasion)
   label variable occasion "occasion: 1=pre-test, 2=post-test"
   label variable outcome "outcome: Learning Outcome"

// Center predictors for analysis
   gen time  = occasion - 1 
   gen treat = group - 1
   label variable time  "time: 0=pre-test, 1=post-test"
   label variable treat "treat: 0=control, 1=treatment"
   
// Sort by person and occasion
   sort personid occasion

********************************************************************************
******                BEGIN CHAPTER 3a TWO-OCCASION MODELS               *******
********************************************************************************

// Open external file to save results to 
log using $filesave\STATA_Chapter3a_Output.log, replace name(STATA_Chapter3a)

display "Chapter 3a Example: Means by group and time for learning outcome"
tabulate group occasion, summarize(outcome)

display "Eq 3a.1: Empty Between-Person Model via STATA MIXED"
mixed outcome , ///
        || personid: , noconstant variance reml  /// Use dftable(default) to get CIs
        residuals(independent,t(occasion)) dfmethod(residual) dftable(default) 
      display "-2LL = " e(ll)*-2   // Print -2LL for model
      estat ic, n(50)              // Information criteria using level-2 N
       
display "Eq 3a.2: Empty Within-Person Model via STATA MIXED"
mixed outcome , ///
         || personid: , noconstant variance reml  ///
         residuals(exchangeable,t(occasion)) dfmethod(repeated) dftable(pvalue)
      display "-2LL = " e(ll)*-2       // Print -2LL for model
      estat ic, n(50)                  // Information criteria using level-2 N
      estat wcorrelation, covariance   // RCOV matrix
      estat wcorrelation               // RCORR matrix

display "Eq 3.7 (top): Between-Person Conditional (Predictor) Model via STATA MIXED"
display "Not using i., manually dummy coding group and time"
mixed outcome c.time c.treat c.time#c.treat,      ///
         || personid: , noconstant variance reml  ///
         residuals(independent,t(occasion)) dfmethod(residual) dftable(pvalue)
      display "-2LL = " e(ll)*-2   // Print -2LL for model
      estat ic, n(50)              // Information criteria using level-2 N
      // Control Group Mean at Pre-Test
      lincom _cons*1 + c.time*0 + c.treat*0 + c.time#c.treat*0, small
      // Control Group Mean at Post-Test
      lincom _cons*1 + c.time*1 + c.treat*0 + c.time#c.treat*0, small
      // Treatment Group Mean at Pre-Test
      lincom _cons*1 + c.time*0 + c.treat*1 + c.time#c.treat*0, small
      // Treatment Group Mean at Post-Test
      lincom _cons*1 + c.time*1 + c.treat*1 + c.time#c.treat*1, small
      // Time Slope for Control Group
      lincom c.time*1 + c.time#c.treat*0, small
      // Time Slope for Treatment Group
      lincom c.time*1 + c.time#c.treat*1, small
      // Group Slope at Pre-Test
      lincom c.treat*1 + c.time#c.treat*0, small
      // Group Slope at Post-Test
      lincom c.treat*1 + c.time#c.treat*1, small
      // Time*Group Interaction Slope
      lincom c.time#c.treat*1, small
      // DF=3 Joint F-test for Model R2
      test (c.time=0)(c.treat=0)(c.time#c.treat=0), small

display "Eq 3.7 (bottom): Within-Person Conditional (Predictor) Model via STATA MIXED"
display "Not using i., manually dummy coding group and time"
mixed outcome c.time c.treat c.time#c.treat,      ///
         || personid: , noconstant variance reml  ///
         residuals(exchangeable,t(occasion)) dfmethod(repeated) dftable(pvalue)
      display "-2LL = " e(ll)*-2      // Print -2LL for model
      estat ic, n(50)                 // Information criteria using level-2 N
      estat wcorrelation, covariance  // RCOV matrix
      estat wcorrelation              // RCORR matrix
      // Control Group Mean at Pre-Test
      lincom _cons*1 + c.time*0 + c.treat*0 + c.time#c.treat*0, small
      // Control Group Mean at Post-Test
      lincom _cons*1 + c.time*1 + c.treat*0 + c.time#c.treat*0, small
      // Treatment Group Mean at Pre-Test
      lincom _cons*1 + c.time*0 + c.treat*1 + c.time#c.treat*0, small
      // Treatment Group Mean at Post-Test
      lincom _cons*1 + c.time*1 + c.treat*1 + c.time#c.treat*1, small
      // Time Slope for Control Group
      lincom c.time*1 + c.time#c.treat*0, small
      // Time Slope for Treatment Group
      lincom c.time*1 + c.time#c.treat*1, small
      // Group Slope at Pre-Test
      lincom c.treat*1 + c.time#c.treat*0, small
      // Group Slope at Post-Test
      lincom c.treat*1 + c.time#c.treat*1, small
      // Time*Group Interaction Slope
      lincom c.treat*1 + c.time#c.treat*1, small
      // DF=3 Joint F-test for Model R2
      test (c.time=0)(c.treat=0)(c.time#c.treat=0), small

 
***** END CHAPTER 3a MODELS ******

// Close external file of saved results
log close STATA_Chapter3a

